#include <cstdio>
#include <algorithm>
#include <cmath>

//#define CHECK_TIME

#ifdef CHECK_TIME
#include <ctime>
#endif

using namespace std;

const char InFile[]="poligon.in";
const char OutFile[]="poligon.out";
const int MaxN=1024;
const int MaxP=2048;

FILE *fin=fopen(InFile,"r");
FILE *fout=fopen(OutFile,"w");

struct s_point
{
	int x,y;
};

struct cmp
{
	inline bool operator() (const s_point &a, const s_point &b)
	{
		return a.x*b.y>b.x*a.y;
	}
};

int N,tstep,nrg,nrp,R[MaxN],Pstart[MaxP],Pend[MaxP];
s_point P[MaxP];

inline bool cautbin(const int &val)
{
	int first=1;
	int step=tstep;
	for(;step;step>>=1)
	{
		int index=first+step;
		if(index<=N)
		{
			if(R[index]<=val)
			{
				first=index;
			}
		}
	}
	return val==R[first];
}

inline int mymax(const int &a, const int &b)
{
	if(a>b)
	{
		return a;
	}
	return b;
}

inline int cmmdc(int a, int b)
{
	int r=a%b;
	while(r)
	{
		a=b;
		b=r;
		r=a%b;
	}
	return b;
}

inline bool same(const s_point &a, const s_point &b)
{
	return a.x==b.x && a.y==b.y;
}

int main()
{
#ifdef CHECK_TIME	
	int start=clock();
#endif
	int MR=0;
	fscanf(fin,"%d",&N);
	for(register int i=1;i<=N;++i)
	{
		fscanf(fin,"%d",&R[i]);
		MR=mymax(MR,R[i]);
	}
	fclose(fin);
	
	tstep=1;
	for(;tstep<=N;tstep<<=1);
	
	sort(R+1,R+1+N);
	
	for(register int i=1;i<=MR;++i)
	{
		for(register int j=1;j<=MR;++j)
		{
			int d=i*i+j*j;
			int dp=(int)(sqrt((double)(d)));
			if(dp*dp==d)
			{
				if(cautbin(dp))
				{
					++nrp;
					int d=cmmdc(i,j);
					P[nrp].x=i/d;
					P[nrp].y=j/d;
				}
			}
		}
	}
	
	sort(P+1,P+1+nrp,cmp());
	nrg=0;
	for(register int i=1;i<=nrp;++i)
	{
		if(!same(P[i],P[i-1]))
		{
			Pend[nrg]=i-1;
			Pstart[++nrg]=i;
		}
	}
	Pend[nrg]=nrp;
	
	fprintf(fout,"%d\n",nrp);
	fprintf(fout,"%d\n",nrg);
	for(register int i=1;i<=nrg;++i)
	{
		fprintf(fout,"%d ",Pend[i]-Pstart[i]+1);
	}
	fclose(fout);
	
#ifdef CHECK_TIME
	printf("%lf",(double)(clock()-start)/(double)(CLOCKS_PER_SEC));
#endif
	return 0;
}
