#include <cstdio>
#include <algorithm>
#include <cmath>

//#define CHECK_TIME

#ifdef CHECK_TIME
#include <ctime>
#endif

using namespace std;

const char InFile[]="stalpi.in";
const char OutFile[]="stalpi.out";
const int MaxN=10111;
const int MaxK=128;
const int INF=1<<30;

FILE *fin=fopen(InFile,"r");
FILE *fout=fopen(OutFile,"w");

struct s_punct
{
	int k,p,ind;
};

struct cmp
{
	inline bool operator() (const s_punct &a, const s_punct &b)
	{
		if(a.k!=b.k)
		{
			return a.k<b.k;
		}
		return a.p<b.p;
	}
};

int N,d,best_sus[MaxN],best_sus_ind[MaxN],jos_start[MaxK],jos_end[MaxK],sol[MaxK],best_sol[MaxK];
s_punct sus[MaxN],jos[MaxN];

inline int myabs(const int &a)
{
	if(a>0)
	{
		return a;
	}
	return -a;
}

inline double dist(const int &a)
{
	return sqrt((double)(d+a*a));
}

inline int cautbin(int start, int end, int val)
{
	int first=start;
	int N=end-start+1;
	int step=1;
	for(;step<=N;step<<=1);
	for(;step;step>>=1)
	{
		int index=first+step;
		if(index<=end)
		{
			if(jos[index].p<=val)
			{
				first=index;
			}
		}
	}
	return first;
}

int main()
{
#ifdef CHECK_TIME
	int start=clock();
#endif
	
	fscanf(fin,"%d %d",&N,&d);
	d*=d;
	for(register int i=1;i<=N;++i)
	{
		fscanf(fin,"%d %d",&sus[i].p,&sus[i].k);
		sus[i].ind=i;
	}
	for(register int i=1;i<=N;++i)
	{
		fscanf(fin,"%d %d",&jos[i].p,&jos[i].k);
		jos[i].ind=i;
	}
	fclose(fin);
	
	sort(sus+1,sus+1+N,cmp());
	sort(jos+1,jos+1+N,cmp());
	
	int k=0;
	for(register int i=1;i<=N;++i)
	{
		if(jos[i].k!=jos[i-1].k)
		{
			jos_end[k]=i-1;
			jos_start[++k]=i;
			best_sol[k]=INF;
		}
	}
	jos_end[k]=N;
	
	for(register int i=1;i<=N;++i)
	{
		int jstart=jos_start[sus[i].k];
		int jend=jos_end[sus[i].k];
		int p=cautbin(jstart,jend,sus[i].p);
		best_sus[i]=myabs(jos[p].p-sus[i].p);
		best_sus_ind[i]=p;
		if(p+1<=jend)
		{
			int val=myabs(jos[p+1].p-sus[i].p);
			if(best_sus[i]>val)
			{
				best_sus[i]=val;
				best_sus_ind[i]=p+1;
			}
		}
		
		if(best_sol[sus[i].k]>best_sus[i])
		{
			best_sol[sus[i].k]=best_sus[i];
			sol[sus[i].k]=i;
		}
	}
	
	double rez=0.0;
	for(register int i=1;i<=k;++i)
	{
		rez+=dist(best_sol[i]);
	}
	fprintf(fout,"%.3lf\n",rez);
	for(register int i=1;i<=k;++i)
	{
		fprintf(fout,"%d %d\n",sus[sol[i]].ind,jos[best_sus_ind[sol[i]]].ind);
	}
	fclose(fout);
	
#ifdef CHECK_TIME
	printf("%lf",(double(clock()-start)/(double)(CLOCKS_PER_SEC)));
#endif
	return 0;
}
